@@ -4,18 +4,13 @@ from django.db.models.signals import pre_save
 
 from .signal_handlers import invalidate_cached_agreements
 
-from .compat import get_middleware_settings_key
-
-
-middleware_settings_key = get_middleware_settings_key()
-MIDDLEWARES = getattr(settings, middleware_settings_key, [])
-
 
 class TOSConfig(AppConfig):
     name = 'tos'
     verbose_name = 'Terms Of Service'
 
     def ready(self):
+        MIDDLEWARES = getattr(settings, 'MIDDLEWARE', [])
         if 'tos.middleware.UserAgreementMiddleware' in MIDDLEWARES:
             TermsOfService = self.get_model('TermsOfService')
 
@@ -24,4 +19,4 @@ class TOSConfig(AppConfig):
                              dispatch_uid='invalidate_cached_agreements')
 
             # Create the TOS key version immediately
-            invalidate_cached_agreements(TermsOfService, None)
+            invalidate_cached_agreements(TermsOfService)
